@@ -7,14 +7,10 @@ import re
 from time import gmtime
 from time import strftime
 
-from unidiff import PatchSet
-from unidiff.errors import UnidiffParseError
-
-from detect_secrets.core.log import CustomLog
+from detect_secrets import VERSION
+from detect_secrets.core.log import log
 from detect_secrets.core.potential_secret import PotentialSecret
-
-
-CustomLogObj = CustomLog()
+from detect_secrets.plugins.core import initialize
 
 
 class SecretsCollection(object):
@@ -26,37 +22,15 @@ class SecretsCollection(object):
 
         :type exclude_regex: str
         :param exclude_regex: for optional regex for ignored paths.
+
+        :type version: str
+        :param version: version of detect-secrets that SecretsCollection
+            is valid at.
         """
         self.data = {}
         self.plugins = plugins
         self.exclude_regex = exclude_regex
-
-    @classmethod
-    def load_baseline_from_file(cls, filename):
-        """Initialize a SecretsCollection object from file.
-
-        :param filename: string; name of file to load
-        :returns: SecretsCollection
-        :raises: IOError
-        """
-        return cls.load_baseline_from_string(
-            cls._get_baseline_string_from_file(filename)
-        )
-
-    @classmethod
-    def _get_baseline_string_from_file(cls, filename):
-        """Used for mocking, because we can't mock `open` (as it's also
-        used in `scan_file`."""
-        try:
-            with codecs.open(filename, encoding='utf-8') as f:
-                return f.read()
-
-        except (IOError, UnicodeDecodeError):
-            CustomLogObj.getLogger().error(
-                "Unable to open baseline file: %s.", filename
-            )
-
-            raise
+        self.version = VERSION
 
     @classmethod
     def load_baseline_from_string(cls, string):
@@ -71,7 +45,7 @@ class SecretsCollection(object):
         try:
             return cls._load_baseline_from_dict(json.loads(string))
         except (IOError, ValueError):
-            CustomLogObj.getLogger().error('Incorrectly formatted baseline!')
+            log.error('Incorrectly formatted baseline!')
             raise
 
     @classmethod
@@ -85,9 +59,24 @@ class SecretsCollection(object):
         :raises: IOError
         """
         result = SecretsCollection()
-        if 'results' not in data or 'exclude_regex' not in data:
+        if not all(key in data for key in (
+            'exclude_regex',
+            'plugins_used',
+            'results',
+        )):
             raise IOError
 
+        result.exclude_regex = data['exclude_regex']
+
+        plugins = []
+        for plugin in data['plugins_used']:
+            plugin_classname = plugin.pop('name')
+            plugins.append(initialize.from_plugin_classname(
+                plugin_classname,
+                **plugin
+            ))
+        result.plugins = tuple(plugins)
+
         for filename in data['results']:
             result.data[filename] = {}
 
@@ -95,22 +84,27 @@ class SecretsCollection(object):
                 secret = PotentialSecret(
                     item['type'],
                     filename,
-                    item['line_number'],
-                    'will be replaced'
+                    secret='will be replaced',
+                    lineno=item['line_number'],
+                    is_secret=item.get('is_secret'),
                 )
                 secret.secret_hash = item['hashed_secret']
                 result.data[filename][secret] = secret
 
-        result.exclude_regex = data['exclude_regex']
+        result.version = (
+            data['version']
+            if 'version' in data
+            else '0.0.0'
+        )
 
         return result
 
     def scan_diff(
-            self,
-            diff,
-            baseline_filename='',
-            last_commit_hash='',
-            repo_name=''
+        self,
+        diff,
+        baseline_filename='',
+        last_commit_hash='',
+        repo_name='',
     ):
         """For optimization purposes, our scanning strategy focuses on looking
         at incremental differences, rather than re-scanning the codebase every time.
@@ -118,7 +112,7 @@ class SecretsCollection(object):
 
         :type diff: str
         :param diff: diff string.
-                     Eg. The output of `git diff <fileA> <fileB>`
+                     e.g. The output of `git diff <fileA> <fileB>`
 
         :type baseline_filename: str
         :param baseline_filename: if there are any baseline secrets, then the baseline
@@ -131,6 +125,11 @@ class SecretsCollection(object):
         :type repo_name: str
         :param repo_name: used for logging only -- the name of the repo
         """
+        # Local imports, so that we don't need to require unidiff for versions of
+        # detect-secrets that don't use it.
+        from unidiff import PatchSet
+        from unidiff.errors import UnidiffParseError
+
         try:
             patch_set = PatchSet.from_string(diff)
         except UnidiffParseError:  # pragma: no cover
@@ -139,7 +138,7 @@ class SecretsCollection(object):
                 'hash': last_commit_hash,
                 'repo_name': repo_name,
             }
-            CustomLogObj.getLogger().error(alert)
+            log.error(alert)
             raise
 
         if self.exclude_regex:
@@ -160,7 +159,7 @@ class SecretsCollection(object):
                         patch_file,
                         plugin,
                         filename,
-                    )
+                    ),
                 )
 
     def scan_file(self, filename, filename_key=None):
@@ -187,7 +186,7 @@ class SecretsCollection(object):
 
             return True
         except IOError:
-            CustomLogObj.getLogger().warning("Unable to open file: %s", filename)
+            log.warning("Unable to open file: %s", filename)
             return False
 
     def get_secret(self, filename, secret, type_=None):
@@ -210,7 +209,7 @@ class SecretsCollection(object):
         if type_:
             # Optimized lookup, because we know the type of secret
             # (and therefore, its hash)
-            tmp_secret = PotentialSecret(type_, filename, 0, 'will be overriden')
+            tmp_secret = PotentialSecret(type_, filename, secret='will be overriden')
             tmp_secret.secret_hash = secret
 
             if tmp_secret in self.data[filename]:
@@ -245,6 +244,7 @@ class SecretsCollection(object):
             'exclude_regex': self.exclude_regex,
             'plugins_used': plugins_used,
             'results': results,
+            'version': self.version,
         }
 
     def _results_accumulator(self, filename):
@@ -256,18 +256,18 @@ class SecretsCollection(object):
                  Caller is responsible for updating the dictionary with
                  results of plugin analysis.
         """
-        results = {}
+        file_results = {}
 
         for plugin in self.plugins:
-            yield results, plugin
+            yield file_results, plugin
 
-        if not results:
+        if not file_results:
             return
 
         if filename not in self.data:
-            self.data[filename] = results
+            self.data[filename] = file_results
         else:
-            self.data[filename].update(results)
+            self.data[filename].update(file_results)
 
     def _extract_secrets_from_file(self, f, filename):
         """Extract secrets from a given file object.
@@ -275,7 +275,6 @@ class SecretsCollection(object):
         :type f:        File object
         :type filename: string
         """
-        log = CustomLogObj.getLogger()
         try:
             log.info("Checking file: %s", filename)
 
@@ -305,7 +304,7 @@ class SecretsCollection(object):
                             line.value,
                             line.target_line_no,
                             filename,
-                        )
+                        ),
                     )
 
         return output
@@ -318,14 +317,18 @@ class SecretsCollection(object):
 
             for secret_hash in self.data[filename]:
                 tmp = self.data[filename][secret_hash].json()
-                del tmp['filename']     # not necessary
+                del tmp['filename']  # not necessary
 
                 output[filename].append(tmp)
 
         return output
 
     def __str__(self):  # pragma: no cover
-        return json.dumps(self.json(), indent=2)
+        return json.dumps(
+            self.json(),
+            indent=2,
+            sort_keys=True,
+        )
 
     def __getitem__(self, key):  # pragma: no cover
         return self.data[key]
